summaryrefslogtreecommitdiffstats
path: root/kbabel/datatools/length
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-12 01:36:19 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-12 01:36:19 +0000
commit99a2774ca6f1cab334de5d43fe36fc44ae889a4c (patch)
treeeff34cf0762227f6baf2a93e8fef48d4bed2651c /kbabel/datatools/length
parent1c104292188541106338d4940b0f04beeb4301a0 (diff)
downloadtdesdk-99a2774ca6f1cab334de5d43fe36fc44ae889a4c.tar.gz
tdesdk-99a2774ca6f1cab334de5d43fe36fc44ae889a4c.zip
TQt4 convert kdesdk
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdesdk@1236185 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kbabel/datatools/length')
-rw-r--r--kbabel/datatools/length/main.cc16
-rw-r--r--kbabel/datatools/length/main.h9
2 files changed, 13 insertions, 12 deletions
diff --git a/kbabel/datatools/length/main.h b/kbabel/datatools/length/main.h
index 6a4ec06f..cff49df8 100644
--- a/kbabel/datatools/length/main.h
+++ b/kbabel/datatools/length/main.h
@@ -20,11 +20,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -41,9 +41,10 @@
class LengthTool : public KDataTool
{
Q_OBJECT
+ TQ_OBJECT
public:
- LengthTool( TQObject* parent, const char* name, const TQStringList & );
+ LengthTool( TQObject* tqparent, const char* name, const TQStringList & );
virtual bool run( const TQString& command, void* data, const TQString& datatype, const TQString& mimetype);
private:
KBabel::Project::Ptr _cache_origin;
diff --git a/kbabel/datatools/length/main.cc b/kbabel/datatools/length/main.cc
index 5b2bc411..2851429e 100644
--- a/kbabel/datatools/length/main.cc
+++ b/kbabel/datatools/length/main.cc
@@ -20,11 +20,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -55,8 +55,8 @@ K_EXPORT_COMPONENT_FACTORY( kbabel_lengthtool, KGenericFactory<LengthTool> ( "kb
using namespace KBabel;
-LengthTool::LengthTool( TQObject* parent, const char* name, const TQStringList & )
- : KDataTool( parent, name ), _cache_origin( 0 )
+LengthTool::LengthTool( TQObject* tqparent, const char* name, const TQStringList & )
+ : KDataTool( tqparent, name ), _cache_origin( 0 )
{
i18n("which check found errors","translation has inconsistent length");
}
@@ -104,7 +104,7 @@ bool LengthTool::run( const TQString& command, void* data, const TQString& datat
if( item->pluralForm() == KDESpecific ) {
str = TQStringList::split( "\\n", item->msgstr().first(), true );
id = TQStringList::split( "\\n",
- item->msgid().first().replace( TQRegExp(_plurals), ""), true );
+ item->msgid().first().tqreplace( TQRegExp(_plurals), ""), true );
} else {
str = item->msgstr();
id = item->msgid();
@@ -113,12 +113,12 @@ bool LengthTool::run( const TQString& command, void* data, const TQString& datat
//Check for translations that are too short or too long
//This may not be totally correct but we check both
//the singular and plural forms against each translated plural.
//FIXME: replace 10% check with configurable setting or a statistical
//based expected length relationship
int idlen, strlen;
for( TQStringList::Iterator i = id.begin() ; i != id.end() ; i++ ) {
TQString iditem = (*i);
- idlen = iditem.replace( TQRegExp(_context),"").length();
+ idlen = iditem.tqreplace( TQRegExp(_context),"").length();
for( TQStringList::Iterator j = str.begin() ; j != str.end() ; j++ ) {
TQString stritem = (*j);
strlen = stritem.length();
@@ -113,12 +113,12 @@ bool LengthTool::run( const TQString& command, void* data, const TQString& datat
//This may not be totally correct but we check both
//the singular and plural forms against each translated plural.
- //FIXME: replace 10% check with configurable setting or a statistical
+ //FIXME: tqreplace 10% check with configurable setting or a statistical
//based expected length relationship
int idlen, strlen;